# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 1.8.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class LessonTypeStrEnum(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    LESSON = 'lesson'
    QUIZ = 'quiz'

    @classmethod
    def from_json(cls, json_str: str) -> LessonTypeStrEnum:
        """Create an instance of LessonTypeStrEnum from a JSON string"""
        return LessonTypeStrEnum(json.loads(json_str))


